@@ -18,27 +18,14 @@ OC.L10N.register(
     "All articles" : "সব লেখা",
     "Starred" : "তারা চিহ্নিত",
     "Settings" : "নিয়ামকসমূহ",
+    "Documentation" : "নথিবদ্ধকরণ",
     "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
     "Rename" : "পূনঃনামকরণ",
     "Delete" : "মুছে",
+    "Previous" : "পূর্ববর্তী",
     "by" : "কর্তৃক",
-    "from" : "হইতে",
     "right" : "ডান",
     "left" : "বাম",
-    "Refresh" : "নবোদ্যম",
-    "Description" : "বিবরণ",
-    "Folder" : "ফোল্ডার",
-    "Go back" : "ফিরে যাও",
-    "New Folder" : "নতুন ফোল্ডার",
-    "Create" : "তৈরী কর",
-    "Deleted feed" : "মুছে ফেলা ফিড",
-    "Collapse" : "ভাঙো",
-    "Subscriptions (OPML)" : "সাবস্ক্রিপশন (OPML)",
-    "Import" : "আমদানি",
-    "Export" : "রপ্তানি",
-    "Unread/Starred Articles" : "অপঠিত/তারকাচিহ্নিত লেখা",
-    "Error when importing: file does not contain valid JSON" : "আমদানীজণিত সমস্যা: ফাইলের JSON সঠিক নয়",
-    "Help" : "সহায়িকা",
-    "Documentation" : "নথিবদ্ধকরণ"
+    "Refresh" : "নবোদ্যম"
 },
 "nplurals=2; plural=(n != 1);");
